@@ -20,6 +20,8 @@ RESET='\033[0m'
 
 echo "Running validation scripts..."
 scripts=(
+    "hack/check-schema-changes.sh"
+    "hack/check-samples.sh"
     "hack/check-docs.sh"
     "hack/test-generated-proto.sh"
 )
