@@ -27,15 +27,15 @@ import (
 	"github.com/GoogleContainerTools/skaffold/v2/testutil"
 )
 
-func TestVerifyPassingTestsWithEnvVar(t *testing.T) {
+func TestLocalVerifyPassingTestsWithEnvVar(t *testing.T) {
 	MarkIntegrationTest(t, CanRunWithoutGcp)
-	t.Setenv("FOO", "foo-var")
 	tmp := t.TempDir()
 	logFile := filepath.Join(tmp, uuid.New().String()+"logs.json")
 
 	rpcPort := randomPort()
 	// `--default-repo=` is used to cancel the default repo that is set by default.
-	out, err := skaffold.Verify("--default-repo=", "--rpc-port", rpcPort, "--event-log-file", logFile).InDir("testdata/verify-succeed").RunWithCombinedOutput(t)
+	out, err := skaffold.Verify("--default-repo=", "--rpc-port", rpcPort,
+		"--event-log-file", logFile, "--env-file", "verify.env").InDir("testdata/verify-succeed").RunWithCombinedOutput(t)
 	logs := string(out)
 
 	testutil.CheckError(t, false, err)
@@ -56,15 +56,15 @@ func TestVerifyPassingTestsWithEnvVar(t *testing.T) {
 	// TODO(aaron-prindle) verify that SUCCEEDED event is found where expected
 }
 
-func TestVerifyOneTestFailsWithEnvVar(t *testing.T) {
+func TestLocalVerifyOneTestFailsWithEnvVar(t *testing.T) {
 	MarkIntegrationTest(t, CanRunWithoutGcp)
-	t.Setenv("FOO", "foo-var")
 	tmp := t.TempDir()
 	logFile := filepath.Join(tmp, uuid.New().String()+"logs.json")
 
 	rpcPort := randomPort()
 	// `--default-repo=` is used to cancel the default repo that is set by default.
-	out, err := skaffold.Verify("--default-repo=", "--rpc-port", rpcPort, "--event-log-file", logFile).InDir("testdata/verify-fail").RunWithCombinedOutput(t)
+	out, err := skaffold.Verify("--default-repo=", "--rpc-port", rpcPort,
+		"--event-log-file", logFile, "--env-file", "verify.env").InDir("testdata/verify-fail").RunWithCombinedOutput(t)
 	logs := string(out)
 
 	testutil.CheckError(t, true, err)
@@ -92,3 +92,59 @@ func TestVerifyNoTestsFails(t *testing.T) {
 	testutil.CheckError(t, true, err)
 	testutil.CheckContains(t, "verify command expects non-zero number of test cases", logs)
 }
+
+func TestKubernetesJobVerifyPassingTestsWithEnvVar(t *testing.T) {
+	MarkIntegrationTest(t, CanRunWithoutGcp)
+	tmp := t.TempDir()
+	logFile := filepath.Join(tmp, uuid.New().String()+"logs.json")
+
+	rpcPort := randomPort()
+	// `--default-repo=` is used to cancel the default repo that is set by default.
+	out, err := skaffold.Verify("--default-repo=", "--rpc-port", rpcPort,
+		"--event-log-file", logFile, "--env-file", "verify.env").InDir("testdata/verify-succeed-k8s").RunWithCombinedOutput(t)
+	logs := string(out)
+
+	testutil.CheckError(t, false, err)
+	testutil.CheckContains(t, "Hello from Docker!", logs)
+	testutil.CheckContains(t, "foo-var", logs)
+	testutil.CheckContains(t, "alpine-1", logs)
+	testutil.CheckContains(t, "alpine-2", logs)
+
+	// verify logs are in the event output as well
+	b, err := os.ReadFile(logFile + ".v2")
+	if err != nil {
+		t.Fatalf("error reading %s", logFile+".v2")
+	}
+	v2EventLogs := string(b)
+	testutil.CheckContains(t, "Hello from Docker!", v2EventLogs)
+	testutil.CheckContains(t, "foo-var", v2EventLogs)
+
+	// TODO(aaron-prindle) verify that SUCCEEDED event is found where expected
+}
+
+func TestKubernetesJobVerifyOneTestFailsWithEnvVar(t *testing.T) {
+	MarkIntegrationTest(t, CanRunWithoutGcp)
+	tmp := t.TempDir()
+	logFile := filepath.Join(tmp, uuid.New().String()+"logs.json")
+
+	rpcPort := randomPort()
+	// `--default-repo=` is used to cancel the default repo that is set by default.
+	out, err := skaffold.Verify("--default-repo=", "--rpc-port", rpcPort,
+		"--event-log-file", logFile, "--env-file", "verify.env").InDir("testdata/verify-fail-k8s").RunWithCombinedOutput(t)
+	logs := string(out)
+
+	testutil.CheckError(t, true, err)
+	testutil.CheckContains(t, "Hello from Docker!", logs)
+	testutil.CheckContains(t, "foo-var", logs)
+
+	// verify logs are in the event output as well
+	b, err := os.ReadFile(logFile + ".v2")
+	if err != nil {
+		t.Fatalf("error reading %s", logFile+".v2")
+	}
+	v2EventLogs := string(b)
+	testutil.CheckContains(t, "Hello from Docker!", v2EventLogs)
+	testutil.CheckContains(t, "foo-var", v2EventLogs)
+
+	// TODO(aaron-prindle) verify that FAILED event is found where expected
+}
