@@ -176,6 +176,16 @@ var TransformAllowlist = map[apimachinery.GroupKind]latest.ResourceFilter{
 		Image:     []string{".*"},
 		Labels:    []string{".*"},
 	},
+	{Group: "kafka.strimzi.io", Kind: "KafkaConnect"}: {
+		GroupKind: "KafkaConnect.kafka.strimzi.io",
+		Image:     []string{".spec.image"},
+		Labels:    []string{".*"},
+	},
+	{Group: "kafka.strimzi.io", Kind: "Kafka"}: {
+		GroupKind: "Kafka.kafka.strimzi.io",
+		Image:     []string{".spec.kafka.image", ".spec.zookeeper.image", ".spec.entityOperator.topicOperator.image", ".spec.entityOperator.userOperator.image", ".spec.kafkaExporter.image."},
+		Labels:    []string{".*"},
+	},
 }
 
 // TransformDenylist is the default denylist on the set of kinds that can be transformed by Skaffold.
