@@ -36,13 +36,15 @@ import (
 )
 
 const (
-	deploymentRolloutSuccess = "successfully rolled out"
-	connectionErrMsg         = "Unable to connect to the server"
-	killedErrMsg             = "signal: killed"
-	defaultPodCheckDeadline  = 30 * time.Second
-	tabHeader                = " -"
-	tab                      = "  "
-	maxLogLines              = 3
+	deploymentRolloutSuccess   = "successfully rolled out"
+	connectionErrMsg           = "Unable to connect to the server"
+	killedErrMsg               = "signal: killed"
+	clientSideThrottleErrMsg   = "due to client-side throttling"
+	couldNotFindResourceErrMsg = "the server could not find the requested resource"
+	defaultPodCheckDeadline    = 30 * time.Second
+	tabHeader                  = " -"
+	tab                        = "  "
+	maxLogLines                = 3
 )
 
 // Type represents a kubernetes resource type to health check.
@@ -99,6 +101,7 @@ type Resource struct {
 	status           Status
 	statusCode       proto.StatusCode
 	done             bool
+	tolerateFailures bool
 	deadline         time.Duration
 	resources        map[string]validator.Resource
 	resoureValidator diag.Diagnose
@@ -126,7 +129,7 @@ func (r *Resource) UpdateStatus(ae *proto.ActionableErr) {
 	}
 }
 
-func NewResource(name string, rType Type, ns string, deadline time.Duration) *Resource {
+func NewResource(name string, rType Type, ns string, deadline time.Duration, tolerateFailures bool) *Resource {
 	return &Resource{
 		name:             name,
 		namespace:        ns,
@@ -134,6 +137,7 @@ func NewResource(name string, rType Type, ns string, deadline time.Duration) *Re
 		status:           newStatus(&proto.ActionableErr{}),
 		deadline:         deadline,
 		resoureValidator: diag.New(nil),
+		tolerateFailures: tolerateFailures,
 	}
 }
 
@@ -202,15 +206,13 @@ func (r *Resource) checkConfigConnectorStatus() *proto.ActionableErr {
 }
 
 func (r *Resource) checkRolloutStatus(ctx context.Context, cfg kubectl.Config) *proto.ActionableErr {
-	kubeCtl := kubectl.NewCLI(cfg, "")
-
-	b, err := kubeCtl.RunOut(ctx, "rollout", "status", string(r.rType), r.name, "--namespace", r.namespace, "--watch=false")
+	b, err := kubectl.NewCLI(cfg, "").RunOut(ctx, "rollout", "status", string(r.rType), r.name, "--namespace", r.namespace, "--watch=false")
 	if ctx.Err() != nil {
 		return &proto.ActionableErr{ErrCode: proto.StatusCode_STATUSCHECK_USER_CANCELLED}
 	}
 
 	details := r.cleanupStatus(string(b))
-	return parseKubectlRolloutError(details, r.deadline, err)
+	return parseKubectlRolloutError(details, r.deadline, r.tolerateFailures, err)
 }
 
 func (r *Resource) CheckStatus(ctx context.Context, cfg kubectl.Config) {
@@ -345,7 +347,7 @@ func (r *Resource) cleanupStatus(msg string) string {
 // $kubectl logs testPod  -f
 // 2020/06/18 17:28:31 service is running
 // Killed: 9
-func parseKubectlRolloutError(details string, deadline time.Duration, err error) *proto.ActionableErr {
+func parseKubectlRolloutError(details string, deadline time.Duration, tolerateFailures bool, err error) *proto.ActionableErr {
 	switch {
 	// deployment rollouts have success messages like `deployment "skaffold-foo" successfully rolled out`
 	case err == nil && strings.Contains(details, deploymentRolloutSuccess):
@@ -364,16 +366,31 @@ func parseKubectlRolloutError(details string, deadline time.Duration, err error)
 			ErrCode: proto.StatusCode_STATUSCHECK_DEPLOYMENT_ROLLOUT_PENDING,
 			Message: details,
 		}
-	case strings.Contains(err.Error(), connectionErrMsg):
-		return &proto.ActionableErr{
-			ErrCode: proto.StatusCode_STATUSCHECK_KUBECTL_CONNECTION_ERR,
-			Message: MsgKubectlConnection,
-		}
 	case strings.Contains(err.Error(), killedErrMsg):
 		return &proto.ActionableErr{
 			ErrCode: proto.StatusCode_STATUSCHECK_KUBECTL_PID_KILLED,
 			Message: fmt.Sprintf("received Ctrl-C or deployments could not stabilize within %v: %s", deadline, msgKubectlKilled),
 		}
+	case tolerateFailures:
+		log.Entry(context.TODO()).Debugf("kubectl rollout encountered error but deployment continuing "+
+			"as skaffold is currently configured to tolerate failures, err: %s", err)
+		return &proto.ActionableErr{
+			ErrCode: proto.StatusCode_STATUSCHECK_DEPLOYMENT_ROLLOUT_PENDING,
+			Message: details,
+		}
+	case strings.Contains(err.Error(), clientSideThrottleErrMsg) ||
+		strings.Contains(err.Error(), couldNotFindResourceErrMsg):
+		log.Entry(context.TODO()).Debugf("kubectl rollout encountered error but deployment continuing "+
+			"as it is likely a transient error, err: %s", err)
+		return &proto.ActionableErr{
+			ErrCode: proto.StatusCode_STATUSCHECK_DEPLOYMENT_ROLLOUT_PENDING,
+			Message: details,
+		}
+	case strings.Contains(err.Error(), connectionErrMsg):
+		return &proto.ActionableErr{
+			ErrCode: proto.StatusCode_STATUSCHECK_KUBECTL_CONNECTION_ERR,
+			Message: MsgKubectlConnection,
+		}
 	// statefulset rollouts that use OnDelete strategy type don't support monitoring rollout, treat it as
 	// if the deployment just completed successfully
 	case strings.Contains(err.Error(), msgStrategyTypeNotSupported):
