@@ -22,6 +22,8 @@ import (
 	"path/filepath"
 	"testing"
 
+	"github.com/google/go-cmp/cmp"
+
 	"github.com/GoogleContainerTools/skaffold/v2/pkg/skaffold/graph"
 	"github.com/GoogleContainerTools/skaffold/v2/pkg/skaffold/render"
 	"github.com/GoogleContainerTools/skaffold/v2/pkg/skaffold/schema/latest"
@@ -68,21 +70,24 @@ func TestRender(t *testing.T) {
 		renderConfig latest.RenderConfig
 		labels       map[string]string
 		expected     string
+		cmpOptions   cmp.Options
 	}{
 		{
 			description: "single manifest with no labels",
 			renderConfig: latest.RenderConfig{
 				Generate: latest.Generate{RawK8s: []string{"pod.yaml"}},
 			},
-			expected: taggedPodYaml,
+			expected:   taggedPodYaml,
+			cmpOptions: []cmp.Option{testutil.YamlObj(t)},
 		},
 		{
 			description: "single manifest with labels",
 			renderConfig: latest.RenderConfig{
 				Generate: latest.Generate{RawK8s: []string{"pod.yaml"}},
 			},
-			labels:   map[string]string{"run.id": "test"},
-			expected: labeledPodYaml,
+			labels:     map[string]string{"run.id": "test"},
+			expected:   labeledPodYaml,
+			cmpOptions: []cmp.Option{testutil.YamlObj(t)},
 		},
 	}
 	for _, test := range tests {
@@ -92,13 +97,13 @@ func TestRender(t *testing.T) {
 				Touch("empty.ignored").
 				Chdir()
 			mockCfg := render.MockConfig{WorkingDir: tmpDirObj.Root()}
-			r, err := New(mockCfg, test.renderConfig, test.labels, "default", "")
+			r, err := New(mockCfg, test.renderConfig, test.labels, "default", "", nil)
 			t.CheckNoError(err)
 			var b bytes.Buffer
 			manifestList, errR := r.Render(context.Background(), &b, []graph.Artifact{{ImageName: "leeroy-web", Tag: "leeroy-web:v1"}},
 				false)
 			t.CheckNoError(errR)
-			t.CheckDeepEqual(test.expected, manifestList.String())
+			t.CheckDeepEqual(test.expected, manifestList.String(), test.cmpOptions)
 		})
 	}
 }
@@ -157,7 +162,7 @@ func TestDependencies(t *testing.T) {
 			rCfg := latest.RenderConfig{
 				Generate: latest.Generate{RawK8s: test.manifests},
 			}
-			r, err := New(mockCfg, rCfg, map[string]string{}, "default", "")
+			r, err := New(mockCfg, rCfg, map[string]string{}, "default", "", nil)
 			t.CheckNoError(err)
 
 			dependencies, err := r.ManifestDeps()
