@@ -35,7 +35,7 @@ import (
 func (r *SkaffoldRunner) VerifyAndLog(ctx context.Context, out io.Writer, artifacts []graph.Artifact) error {
 	defer r.verifier.GetLogger().Stop()
 
-	// Logs should be retrieved up to just before the deploys
+	// Logs should be retrieved up to just before the verify tests run
 	r.verifier.GetLogger().SetSince(time.Now())
 
 	// Start logger immediately as it needs to be running to get test logs immediately
@@ -48,12 +48,6 @@ func (r *SkaffoldRunner) VerifyAndLog(ctx context.Context, out io.Writer, artifa
 		return err
 	}
 
-	defer r.verifier.GetAccessor().Stop()
-
-	if err := r.verifier.GetAccessor().Start(ctx, out); err != nil {
-		log.Entry(ctx).Warn("Error starting port forwarding:", err)
-	}
-
 	return nil
 }
 
